from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    ambient_log_level: str = "DEBUG"
    ambient_config: str = "~/.ambientctl/config.json"

    backend_api_url: str = "https://api.ambientlabsdev.io"
    event_bus_api: str = "https://events.ambientlabsdev.io"
    connection_service_url: str = "wss://sockets.ambientlabsdev.io"


settings = Settings()



import logging

from ambient_edge_server.config import settings

logger = logging.getLogger("ambient_edge_server")
# load basic configuration
logging.basicConfig()
logger.setLevel(settings.ambient_log_level)



import uvicorn

from ambient_edge_server.app import app
from ambient_edge_server.utils import logger


def run():
    logger.debug("running server ...")
    logger.debug("running app: %s ...", app)
    uvicorn.run(app, host="0.0.0.0", port=7417)


if __name__ == "__main__":
    run()



from typing import List

from docker import DockerClient

from ambient_edge_server.event_handlers.base_handler import BaseHandler
from ambient_edge_server.event_handlers.deploy_service_handler import (
    DeployServiceHandler,
)
from ambient_edge_server.event_handlers.test_handler import TestHandler
from ambient_edge_server.services.event_service import EventService


class HandlerService:
    def __init__(self, event_service: EventService, docker_client: DockerClient):
        self._handlers: List[BaseHandler] = [
            TestHandler(event_service),
            DeployServiceHandler(event_service, docker_client=docker_client),
        ]

    async def start(self):
        for handler in self._handlers:
            await handler.subscribe()

    def get_handlers(self):
        return self._handlers



# setup.py
from setuptools import setup, find_packages

PACKAGE_NAME = 'ambient_edge_server'
VERSION = '0.1.1'

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    packages=find_packages(),
    install_requires=[
        'fastapi==0.111.0',
        'pydantic==2.7.1',
        'ambient_event_bus_client==0.1.4',
        'ambient_backend_api_client==0.1.11',
    ],
    entry_points={
        'console_scripts': [
            'ambient_edge_server=ambient_edge_server.run:run',
        ],
    },
)
